% Initizes paramters for Performance Simulation of a 
% feedback-controlled large transport a/c

clear

%-------------------------------------------------------------------
% General Constants

d2r=pi/180;r2d=1/d2r;g=32.2;fps2mph=3600/5280;m2f=5280;f2m=1/m2f;
kts2mph=6080/5280;

%-------------------------------------------------------------------
% Aircraft Configuration Constants

S=3010;b=146;AR=b^2/S;e=.95;ARe=AR*e;piARe=pi*ARe;CDob=0.02;
Wmax=327000;Wempty=157000;MaxFuel=170000;Vmin=200/fps2mph;
Wnom=Wempty+0.75*MaxFuel;
Kwdot=-4e-6;              %Fuel Flow Rate = Kwdot*Thrust
Tmax=72000;
PHImax=d2r*30;

%-------------------------------------------------------------------
% Atmospheric Constants

rho=1.2682e-03;           % At an altitude of 20,000 ft

%-------------------------------------------------------------------
% Calculate Drag Polar Coefficients

KD0=0.5*rho*CDob*S;KD1=2/(rho*pi*AR*e*S);CD1=KD0;CD2=KD1;

% Lift Model   alpha = KL(L/V^2)+alpha0

KL=2/(rho*S*0.1);alpha0=-0.05;

%-------------------------------------------------------------------
% Define The Wind:

W=winds(0);
Wx=W(1);Wy=W(2);Wh=W(3);
Dx=Wx;Dy=Wy;Dh=Wh;

%-------------------------------------------------------------------
% Define Initial States, Controls (Assume Initially in Trim) 

Wo=Wnom;Mo=Wo/g;
Vnom=400/fps2mph;
Vo=400/fps2mph;GAMo=0*d2r;PSIo=0*d2r;Xo=0;Yo=0;Ho=10000;

PHIo=0;
Lo=Wo*cos(GAMo)/cos(PHIo);
Do=KD0*(Vo^2)+KD1*(Lo^2/Vo^2);
To=Do+Wo*sin(GAMo);

%-------------------------------------------------------------------
% Define Control Lag Time Constants (p(*) = 1/time const.)

pT=2;pL=2.5;pf=1;

%-------------------------------------------------------------------
% Define Guidance Law Gains
% Designed for Wo=284500;Ho=20,000 ft, 
% Vo=400 mph, GAMo=PHIo=0, 
% Vc = 450 mph, GAMc = 5 deg, PSIc = 10 deg
% All integrations start at correct initial conditions
%
KTP=0.08;KTI=0.002;             % 2*KT1=KTP, 2*KT2=KTI
KLP=.5;KLI=0.01;			  % 2*KL1=KLP, 2*KL2=KLI
Kf=0.075;						  % Kf1=Kf

KT1=KTP;KT2=KTI;
KL1=KLP;KL2=KLI;
Kf1=Kf;

return
